
.. DO NOT EDIT.
.. THIS FILE WAS AUTOMATICALLY GENERATED BY SPHINX-GALLERY.
.. TO MAKE CHANGES, EDIT THE SOURCE PYTHON FILE:
.. "_as_gen/sph/run_sph_shear_test.py"
.. LINE NUMBERS ARE GIVEN BELOW.

.. only:: html

    .. note::
        :class: sphx-glr-download-link-note

        :ref:`Go to the end <sphx_glr_download__as_gen_sph_run_sph_shear_test.py>`
        to download the full example code.

.. rst-class:: sphx-glr-example-title

.. _sphx_glr__as_gen_sph_run_sph_shear_test.py:


Shearing box in SPH
========================

This simple example shows how to run an unstratified shearing box simulaiton

.. GENERATED FROM PYTHON SOURCE LINES 7-22

.. code-block:: Python
   :lineno-start: 9



    import shamrock

    # If we use the shamrock executable to run this script instead of the python interpreter,
    # we should not initialize the system as the shamrock executable needs to handle specific MPI logic
    if not shamrock.sys.is_initialized():
        shamrock.change_loglevel(1)
        shamrock.sys.init("0:0")

    from math import exp

    import matplotlib.pyplot as plt
    import numpy as np








.. GENERATED FROM PYTHON SOURCE LINES 24-25

Initialize context & attach a SPH model to it

.. GENERATED FROM PYTHON SOURCE LINES 25-31

.. code-block:: Python
   :lineno-start: 25

    ctx = shamrock.Context()
    ctx.pdata_layout_new()

    model = shamrock.get_Model_SPH(context=ctx, vector_type="f64_3", sph_kernel="M4")









.. GENERATED FROM PYTHON SOURCE LINES 32-33

Setup parameters

.. GENERATED FROM PYTHON SOURCE LINES 33-53

.. code-block:: Python
   :lineno-start: 33

    gamma = 5.0 / 3.0
    rho = 1
    uint = 1

    dr = 0.02
    bmin = (-0.6, -0.6, -0.1)
    bmax = (0.6, 0.6, 0.1)
    pmass = -1

    bmin, bmax = model.get_ideal_fcc_box(dr, bmin, bmax)
    xm, ym, zm = bmin
    xM, yM, zM = bmax

    Omega_0 = 1
    eta = 0.00
    q = 3.0 / 2.0

    shear_speed = -q * Omega_0 * (xM - xm)









.. GENERATED FROM PYTHON SOURCE LINES 54-55

Generate the config & init the scheduler

.. GENERATED FROM PYTHON SOURCE LINES 55-73

.. code-block:: Python
   :lineno-start: 55

    cfg = model.gen_default_config()
    # cfg.set_artif_viscosity_Constant(alpha_u = 1, alpha_AV = 1, beta_AV = 2)
    # cfg.set_artif_viscosity_VaryingMM97(alpha_min = 0.1,alpha_max = 1,sigma_decay = 0.1, alpha_u = 1, beta_AV = 2)
    cfg.set_artif_viscosity_VaryingCD10(
        alpha_min=0.0, alpha_max=1, sigma_decay=0.1, alpha_u=1, beta_AV=2
    )
    cfg.set_boundary_shearing_periodic((1, 0, 0), (0, 1, 0), shear_speed)
    cfg.set_eos_adiabatic(gamma)
    cfg.add_ext_force_shearing_box(Omega_0=Omega_0, eta=eta, q=q)
    cfg.set_units(shamrock.UnitSystem())
    cfg.print_status()
    model.set_solver_config(cfg)

    model.init_scheduler(int(1e7), 1)

    model.resize_simulation_box(bmin, bmax)






.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    ----- SPH Solver configuration ----- 
    units :  
    unit_length      : 1 
    unit_mass        : 1 
    unit_current     : 1 
    unit_temperature : 1 
    unit_qte         : 1 
    unit_lumint      : 1 
    part mass 0 ( can be changed using .set_part_mass() ) 
    cfl force 0 
    cfl courant 0 
    --- artificial viscosity config 
      Config Type : VaryingCD10 (Cullen & Dehnen 2010) 
      alpha_min   = 0 
      alpha_max   = 1 
      sigma_decay = 0.1 
      alpha_u     = 1 
      beta_AV     = 2 
    --- artificial viscosity config (deduced) 
    ------------- 
    EOS config f64_3 : 
    adiabatic :  
    gamma 1.6666666666666667 
    --- Bondaries config 
      Config Type : ShearingPeriodic (Stone 2010) 
      shear_base   = (1,0,0) 
      shear_dir   = (0,1,0) 
      shear_speed = -1.8000000000000003 
    --- Bondaries config config (deduced) 
    ------------- 
    ------------------------------------ 




.. GENERATED FROM PYTHON SOURCE LINES 74-76

Add the particles & set fields values
Note that every field that are not mentionned are set to zero

.. GENERATED FROM PYTHON SOURCE LINES 76-122

.. code-block:: Python
   :lineno-start: 76

    model.add_cube_fcc_3d(dr, bmin, bmax)

    vol_b = (xM - xm) * (yM - ym) * (zM - zm)

    totmass = rho * vol_b
    # print("Total mass :", totmass)

    pmass = model.total_mass_to_part_mass(totmass)

    model.set_value_in_a_box("uint", "f64", 1, bmin, bmax)
    # model.set_value_in_a_box("vxyz","f64_3", (-10,0,0) , bmin,bmax)

    pen_sz = 0.1

    mm = 1
    MM = 0


    def vel_func(r):
        global mm, MM
        x, y, z = r

        s = (x - (xM + xm) / 2) / (xM - xm)
        vel = (shear_speed) * s

        mm = min(mm, vel)
        MM = max(MM, vel)

        return (0, vel, 0.0)
        # return (1,0,0)


    model.set_field_value_lambda_f64_3("vxyz", vel_func)
    # print("Current part mass :", pmass)
    model.set_particle_mass(pmass)


    tot_u = pmass * model.get_sum("uint", "f64")
    # print("total u :",tot_u)

    print(f"v_shear = {shear_speed} | dv = {MM-mm}")


    model.set_cfl_cour(0.3)
    model.set_cfl_force(0.25)





.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    Info: Add fcc lattice size : ( 31 34 6 )                                              [SPH][rank=0] 
    Info: Push particles :                                                              [Model][rank=0]
      rank = 0  patch id=0, add N=6120 particles, coords = (-0.6,-0.6,-0.1) (0.6000000000000002,0.5777945491468365,0.09595917942265422)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 17.36 us   (58.5%)  
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.56 us    (0.5%)
       patch tree reduce : 872.00 ns  (0.2%)
       gen split merge   : 641.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 812.00 ns  (0.2%)
       LB compute        : 452.40 us  (97.3%)
       LB move op cnt    : 0
       LB apply          : 3.27 us    (0.7%)  
    Info: current particle counts : min =  6120 max =  6120                             [Model][rank=0] 
    v_shear = -1.8000000000000003 | dv = 1.7700000000000002




.. GENERATED FROM PYTHON SOURCE LINES 123-129

.. code-block:: Python
   :lineno-start: 123

    dump_folder = "_to_trash"
    import os

    os.system("mkdir -p " + dump_folder)






.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    0



.. GENERATED FROM PYTHON SOURCE LINES 130-131

Perform the plot

.. GENERATED FROM PYTHON SOURCE LINES 131-146

.. code-block:: Python
   :lineno-start: 131

    def plot():
        dic = ctx.collect_data()
        fig, axs = plt.subplots(2, 1, figsize=(5, 8), sharex=True)
        fig.suptitle("t = {:.2f}".format(model.get_time()))
        axs[0].scatter(dic["xyz"][:, 0], dic["xyz"][:, 1], s=1)
        axs[1].scatter(dic["xyz"][:, 0], dic["vxyz"][:, 1], s=1)

        axs[0].set_ylabel("y")
        axs[1].set_ylabel("vy")
        axs[1].set_xlabel("x")

        plt.tight_layout()
        plt.show()









.. GENERATED FROM PYTHON SOURCE LINES 147-148

Performing the timestep loop

.. GENERATED FROM PYTHON SOURCE LINES 148-163

.. code-block:: Python
   :lineno-start: 148

    model.timestep()

    dt_stop = 0.1
    for i in range(2):

        t_target = i * dt_stop
        # skip if the model is already past the target
        if model.get_time() > t_target:
            continue

        model.evolve_until(i * dt_stop)

        # Dump name is "dump_xxxx.sham" where xxxx is the timestep
        model.do_vtk_dump(dump_folder + "/dump_{:04}.vtk".format(i), True)
        plot()



.. rst-class:: sphx-glr-horizontal


    *

      .. image-sg:: /_as_gen/sph/images/sphx_glr_run_sph_shear_test_001.png
         :alt: t = 0.00
         :srcset: /_as_gen/sph/images/sphx_glr_run_sph_shear_test_001.png
         :class: sphx-glr-single-img

    *

      .. image-sg:: /_as_gen/sph/images/sphx_glr_run_sph_shear_test_002.png
         :alt: t = 0.10
         :srcset: /_as_gen/sph/images/sphx_glr_run_sph_shear_test_002.png
         :class: sphx-glr-single-img


.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    ---------------- t = 0, dt = 0 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 16.27 us   (1.9%)
       patch tree reduce : 3.46 us    (0.4%)
       gen split merge   : 561.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 991.00 ns  (0.1%)
       LB compute        : 818.18 us  (95.9%)
       LB move op cnt    : 0
       LB apply          : 3.62 us    (0.4%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.77 us    (70.5%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 0.741503267973856  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.022000000000000002 unconverged cnt = 6120   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 0.7684640522875816  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.024200000000000003 unconverged cnt = 6120   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 0.7684640522875816  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.026620000000000005 unconverged cnt = 6120   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 0.794607843137255  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.029282000000000006 unconverged cnt = 6120   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 0.8504901960784312  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.03221020000000001 unconverged cnt = 6120   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.320424836601307  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.03543122000000001 unconverged cnt = 6120   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.320424836601307  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.038974342000000016 unconverged cnt = 6120   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4184640522875813  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 2.8314338416863407e-07, max = 2.831433850588215e-07
      iterations = 3  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (0,0.004154393760827157,0)
        sum a = (5.6948709491889e-17,-8.766053124257185e-18,0.005082303061895428)
        sum e = 0.3143698998713959
        sum de = 9.604356448640433e-05  
    Info: cfl dt = 0.00011089173088629873 cfl multiplier : 0.01                    [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    2.5494e+04    |        6120 |   2.401e-01   |    0 % |   1 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 0 (tsim/hr)                                             [sph::Model][rank=0] 
    Info: iteration since start : 1                                                       [SPH][rank=0] 
    Info: time since start : 17.560140245 (s)                                             [SPH][rank=0] 
    Info: dump to _to_trash/dump_0000.vtk                                            [VTK Dump][rank=0]
                  - took 6.14 ms, bandwidth = 79.95 MB/s  
    adding ->  xyz
    adding ->  vxyz
    adding ->  axyz
    adding ->  axyz_ext
    adding ->  hpart
    adding ->  uint
    adding ->  duint
    adding ->  alpha_AV
    adding ->  divv
    adding ->  dtdivv
    adding ->  curlv
    adding ->  soundspeed
    ---------------- t = 0, dt = 0.00011089173088629873 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 9.77 us    (2.0%)
       patch tree reduce : 1293.00 ns (0.3%)
       gen split merge   : 721.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 1041.00 ns (0.2%)
       LB compute        : 457.20 us  (95.1%)
       LB move op cnt    : 0
       LB apply          : 3.93 us    (0.8%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.98 us    (70.7%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4470588235294115  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 1.5839830969886152e-09, max = 3.408253654510689e-09
      iterations = 0  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (6.315145049214027e-21,-4.3007972628265963e-17,5.635853834223198e-07)
        sum a = (5.19318507104892e-17,6.088338327277574e-18,0.00508230303064696)
        sum e = 0.31436991054897867
        sum de = 9.74466885364498e-05  
    Info: cfl dt = 0.0037703106533756884 cfl multiplier : 0.34                     [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.1476e+05    |        6120 |   5.333e-02   |    0 % |   1 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 7.485532660484111 (tsim/hr)                             [sph::Model][rank=0] 
    ---------------- t = 0.00011089173088629873, dt = 0.0037703106533756884 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 6.99 us    (1.8%)
       patch tree reduce : 1373.00 ns (0.4%)
       gen split merge   : 651.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 1123.00 ns (0.3%)
       LB compute        : 358.87 us  (94.6%)
       LB move op cnt    : 0
       LB apply          : 3.41 us    (0.9%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.67 us    (66.1%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4388888888888887  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 7.172685023217074e-12, max = 3.3201651540132534e-11
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (2.0183625283288808e-19,3.778270492576636e-18,1.9725446641821508e-05)
        sum a = (6.111891063456037e-17,-5.003473743189519e-18,0.005082264782670164)
        sum e = 0.3143702833343977
        sum de = 0.00013824059786473694  
    Info: cfl dt = 0.006209449394346196 cfl multiplier : 0.56                      [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.0352e+05    |        6120 |   5.912e-02   |    0 % |   1 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 229.58851648871095 (tsim/hr)                            [sph::Model][rank=0] 
    ---------------- t = 0.003881202384261987, dt = 0.006209449394346196 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 5.21 us    (1.5%)
       patch tree reduce : 1113.00 ns (0.3%)
       gen split merge   : 570.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 992.00 ns  (0.3%)
       LB compute        : 329.61 us  (94.9%)
       LB move op cnt    : 0
       LB apply          : 3.37 us    (1.0%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 3.19 us    (67.9%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4367647058823527  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 2.3294096404573677e-10, max = 1.0880275964821347e-09
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (5.986590816098565e-19,-8.32023395705706e-18,5.128344051510254e-05)
        sum a = (5.850965248209674e-17,5.758902876894751e-19,0.005082044319848336)
        sum e = 0.3143712315922659
        sum de = 0.00020394600495906925  
    Info: cfl dt = 0.007834596847674341 cfl multiplier : 0.7066666666666667        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.1282e+05    |        6120 |   5.425e-02   |    0 % |   1 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 412.08535132951255 (tsim/hr)                            [sph::Model][rank=0] 
    ---------------- t = 0.010090651778608184, dt = 0.007834596847674341 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 3.15 us    (1.0%)
       patch tree reduce : 612.00 ns  (0.2%)
       gen split merge   : 581.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 631.00 ns  (0.2%)
       LB compute        : 302.27 us  (96.3%)
       LB move op cnt    : 0
       LB apply          : 2.25 us    (0.7%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.41 us    (69.0%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4455882352941174  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 1.3550983973723722e-09, max = 6.545525037921152e-09
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (1.0489100801015626e-18,-1.9011935563710095e-17,9.109852444675989e-05)
        sum a = (3.836615128341325e-17,2.6808543685796116e-18,0.005081486569882731)
        sum e = 0.3143730498982785
        sum de = 0.00028163943820289555  
    Info: cfl dt = 0.00891668243491238 cfl multiplier : 0.8044444444444444         [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.1091e+05    |        6120 |   5.518e-02   |    0 % |   1 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 511.14810289121317 (tsim/hr)                            [sph::Model][rank=0] 
    ---------------- t = 0.017925248626282524, dt = 0.00891668243491238 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 5.20 us    (1.4%)
       patch tree reduce : 1062.00 ns (0.3%)
       gen split merge   : 551.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 973.00 ns  (0.3%)
       LB compute        : 353.07 us  (95.2%)
       LB move op cnt    : 0
       LB apply          : 3.24 us    (0.9%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.38 us    (70.8%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4475490196078429  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 3.615263896248438e-09, max = 1.8821916322165866e-08
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (1.3122342115785653e-18,-3.336132456211285e-18,0.00013640634161461525)
        sum a = (7.399280524491505e-17,-3.84197699408773e-18,0.005080472285302088)
        sum e = 0.31437589351354017
        sum de = 0.0003608568219550676  
    Info: cfl dt = 0.009636396780122314 cfl multiplier : 0.8696296296296296        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.0738e+05    |        6120 |   5.699e-02   |    0 % |   1 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 563.2219616046577 (tsim/hr)                             [sph::Model][rank=0] 
    ---------------- t = 0.026841931061194903, dt = 0.009636396780122314 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 5.76 us    (1.7%)
       patch tree reduce : 1182.00 ns (0.4%)
       gen split merge   : 591.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 1093.00 ns (0.3%)
       LB compute        : 311.84 us  (94.3%)
       LB move op cnt    : 0
       LB apply          : 3.33 us    (1.0%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.38 us    (71.5%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4460784313725488  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 5.752376507485498e-09, max = 3.4459765836674773e-08
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (2.1844205723774023e-18,-1.6077746776921855e-18,0.0001853592663594488)
        sum a = (4.141401476421019e-17,-7.070126341453038e-19,0.005078921976555799)
        sum e = 0.3143797778012691
        sum de = 0.0004329654653391086  
    Info: cfl dt = 0.010114315298959963 cfl multiplier : 0.9130864197530864        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.0834e+05    |        6120 |   5.649e-02   |    0 % |   1 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 614.1480070247019 (tsim/hr)                             [sph::Model][rank=0] 
    ---------------- t = 0.036478327841317215, dt = 0.010114315298959963 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 4.10 us    (1.3%)
       patch tree reduce : 1292.00 ns (0.4%)
       gen split merge   : 551.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 1002.00 ns (0.3%)
       LB compute        : 306.27 us  (95.0%)
       LB move op cnt    : 0
       LB apply          : 2.98 us    (0.9%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.29 us    (70.7%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4460784313725488  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 5.818251260610762e-09, max = 4.486423362805652e-08
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (2.4457526490474497e-18,-3.472793303815121e-17,0.00023672161491404577)
        sum a = (3.43322697385629e-17,4.401440189428226e-18,0.005076787484773814)
        sum e = 0.31438460229587495
        sum de = 0.0004912658954562416  
    Info: cfl dt = 0.010430975181113323 cfl multiplier : 0.9420576131687243        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.0750e+05    |        6120 |   5.693e-02   |    0 % |   1 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 639.6075268822484 (tsim/hr)                             [sph::Model][rank=0] 
    ---------------- t = 0.04659264314027718, dt = 0.010430975181113323 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 5.04 us    (1.5%)
       patch tree reduce : 1133.00 ns (0.3%)
       gen split merge   : 682.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 992.00 ns  (0.3%)
       LB compute        : 322.27 us  (94.8%)
       LB move op cnt    : 0
       LB apply          : 2.97 us    (0.9%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.38 us    (70.8%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4483660130718952  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 3.405816618081674e-09, max = 4.2910854860000134e-08
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (2.7687402939544358e-18,-2.893994419845934e-18,0.00028966666470606504)
        sum a = (5.2166007921276686e-17,-7.135285178488415e-18,0.0050740421695320065)
        sum e = 0.3143901775107707
        sum de = 0.0005310720353439191  
    Info: cfl dt = 0.01064024299013669 cfl multiplier : 0.9613717421124829         [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.1052e+05    |        6120 |   5.537e-02   |    0 % |   1 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 678.1378165849866 (tsim/hr)                             [sph::Model][rank=0] 
    ---------------- t = 0.0570236183213905, dt = 0.01064024299013669 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 3.86 us    (1.2%)
       patch tree reduce : 1142.00 ns (0.4%)
       gen split merge   : 611.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 952.00 ns  (0.3%)
       LB compute        : 302.12 us  (95.1%)
       LB move op cnt    : 0
       LB apply          : 2.90 us    (0.9%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.38 us    (71.2%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4483660130718952  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 6.124547504410648e-10, max = 2.9116102549298282e-08
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (3.417738011751374e-18,-6.431098710768742e-19,0.0003436413881745103)
        sum a = (6.22987566126383e-17,-1.771660928529598e-17,0.0050706729699212345)
        sum e = 0.3143962517375111
        sum de = 0.0005501730733550375  
    Info: cfl dt = 0.010583003685891922 cfl multiplier : 0.9742478280749886        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.1208e+05    |        6120 |   5.460e-02   |    0 % |   1 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 701.4905393054572 (tsim/hr)                             [sph::Model][rank=0] 
    ---------------- t = 0.0676638613115272, dt = 0.010583003685891922 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 6.05 us    (1.7%)
       patch tree reduce : 1443.00 ns (0.4%)
       gen split merge   : 581.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 1142.00 ns (0.3%)
       LB compute        : 336.10 us  (94.4%)
       LB move op cnt    : 0
       LB apply          : 3.55 us    (1.0%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.42 us    (72.2%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4460784313725488  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 2.582426396378962e-10, max = 1.762618766251557e-08
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (4.1282441016172494e-18,-1.680124538188334e-17,0.0003972864143538687)
        sum a = (4.909490707209122e-17,-2.156129468887494e-17,0.005066752443936444)
        sum e = 0.31440241760719223
        sum de = 0.0005615715602514454  
    Info: cfl dt = 0.010635095941600751 cfl multiplier : 0.9828318853833258        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.1114e+05    |        6120 |   5.506e-02   |    0 % |   1 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 691.9056892856759 (tsim/hr)                             [sph::Model][rank=0] 
    ---------------- t = 0.07824686499741912, dt = 0.010635095941600751 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 5.08 us    (1.4%)
       patch tree reduce : 1072.00 ns (0.3%)
       gen split merge   : 571.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 972.00 ns  (0.3%)
       LB compute        : 333.06 us  (94.3%)
       LB move op cnt    : 0
       LB apply          : 4.80 us    (1.4%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 3.12 us    (66.3%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4477124183006533  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 1.06301328742834e-09, max = 6.683179663726466e-09
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (4.579881197357637e-18,-2.5402839907536532e-17,0.0004511510672369989)
        sum a = (4.0979413171646526e-17,-6.481341669446623e-19,0.005062240947242894)
        sum e = 0.3144087119423163
        sum de = 0.0005739543750557067  
    Info: cfl dt = 0.010652394617585905 cfl multiplier : 0.9885545902555505        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.1425e+05    |        6120 |   5.356e-02   |    0 % |   1 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 714.7675015881283 (tsim/hr)                             [sph::Model][rank=0] 
    ---------------- t = 0.08888196093901987, dt = 0.010652394617585905 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 3.72 us    (1.2%)
       patch tree reduce : 621.00 ns  (0.2%)
       gen split merge   : 570.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 681.00 ns  (0.2%)
       LB compute        : 294.74 us  (95.6%)
       LB move op cnt    : 0
       LB apply          : 2.94 us    (1.0%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.29 us    (67.4%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4452614379084965  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 2.3014687575276836e-10, max = 6.215082235314744e-09
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (4.970598705701095e-18,-3.890814720015089e-17,0.0005050520653562442)
        sum a = (7.083001099614246e-17,-1.4940685818343064e-17,0.0050571481484674215)
        sum e = 0.3144151462463685
        sum de = 0.0005908429305553166  
    Info: cfl dt = 0.010647033142926733 cfl multiplier : 0.9923697268370336        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.1472e+05    |        6120 |   5.335e-02   |    0 % |   1 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 718.8301841654676 (tsim/hr)                             [sph::Model][rank=0] 
    ---------------- t = 0.09953435555660578, dt = 0.0004656444433942253 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 6120 min = 6120                            [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 6120 min = 6120                       [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 6120
        max = 6120
        avg = 6120
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 3.49 us    (1.1%)
       patch tree reduce : 762.00 ns  (0.2%)
       gen split merge   : 651.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 681.00 ns  (0.2%)
       LB compute        : 310.19 us  (95.9%)
       LB move op cnt    : 0
       LB apply          : 2.83 us    (0.9%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.32 us    (69.6%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.4452614379084965  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 1.0704970741195936e-11, max = 7.460773315354855e-07
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (5.164505124348541e-18,-2.1343208846363764e-17,0.0005073797730398672)
        sum a = (5.699812447212187e-17,-3.6187490987743646e-18,0.0050569124381528545)
        sum e = 0.3144144614858832
        sum de = 0.0005914932822185097  
    Info: cfl dt = 0.010671519169061247 cfl multiplier : 0.9949131512246892        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.1251e+05    |        6120 |   5.440e-02   |    0 % |   1 % |   10.01 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 30.816700967647407 (tsim/hr)                            [sph::Model][rank=0] 
    Info: iteration since start : 14                                                      [SPH][rank=0] 
    Info: time since start : 18.386476646000002 (s)                                       [SPH][rank=0] 
    Info: dump to _to_trash/dump_0001.vtk                                            [VTK Dump][rank=0]
                  - took 2.58 ms, bandwidth = 190.06 MB/s  
    adding ->  xyz
    adding ->  vxyz
    adding ->  axyz
    adding ->  axyz_ext
    adding ->  hpart
    adding ->  uint
    adding ->  duint
    adding ->  alpha_AV
    adding ->  divv
    adding ->  dtdivv
    adding ->  curlv
    adding ->  soundspeed





.. rst-class:: sphx-glr-timing

   **Total running time of the script:** (0 minutes 2.031 seconds)

**Estimated memory usage:**  70 MB


.. _sphx_glr_download__as_gen_sph_run_sph_shear_test.py:

.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-example

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download Jupyter notebook: run_sph_shear_test.ipynb <run_sph_shear_test.ipynb>`

    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download Python source code: run_sph_shear_test.py <run_sph_shear_test.py>`

    .. container:: sphx-glr-download sphx-glr-download-zip

      :download:`Download zipped: run_sph_shear_test.zip <run_sph_shear_test.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
